<!--
    =====================================
    generator=datazen
    version=3.1.0
    hash=92b365abaf1adf985cc1ca3950a80a37
    =====================================
-->

# vcorelib ([1.2.5](https://pypi.org/project/vcorelib/))

[![python](https://img.shields.io/pypi/pyversions/vcorelib.svg)](https://pypi.org/project/vcorelib/)
![Build Status](https://github.com/vkottler/vcorelib/workflows/Python%20Package/badge.svg)
[![codecov](https://codecov.io/gh/vkottler/vcorelib/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/vkottler/vcorelib)
![PyPI - Status](https://img.shields.io/pypi/status/vcorelib)
![Dependents (via libraries.io)](https://img.shields.io/librariesio/dependents/pypi/vcorelib)

*A collection of core Python utilities.*

See also: [generated documentation](https://vkottler.github.io/python/pydoc/vcorelib.html)
(created with [`pydoc`](https://docs.python.org/3/library/pydoc.html)).

## Python Version Support

This package is tested with the following Python minor versions:

* [`python3.7`](https://docs.python.org/3.7/)
* [`python3.8`](https://docs.python.org/3.8/)
* [`python3.9`](https://docs.python.org/3.9/)
* [`python3.10`](https://docs.python.org/3.10/)

## Platform Support

This package is tested on the following platforms:

* `ubuntu-latest`
* `macos-latest`
* `windows-latest`

# Introduction

Core technologies shared between a number of other Python packages.

# Internal Dependency Graph

A coarse view of the internal structure and scale of
`vcorelib`'s source.
Generated using [pydeps](https://github.com/thebjorn/pydeps) (via
`mk python-deps`).

![vcorelib's Dependency Graph](im/pydeps.svg)
